@@ -49,7 +49,7 @@
 int get_event_bits(int func, int nr, word *cap, word *cond)
 {
   smapi_outparm_t *result;
-  word tmp;
+  word tmp = 0;
 
   if((result=do_smapi(func,0x00,0,0,0,0,0,FALSE))==NULL) return 1;
   
