@@ -25,7 +25,7 @@
 #include <sys/stat.h>
 #include <linux/unistd.h>
 #include <linux/types.h>
-#include <linux/errno.h>
+#include <errno.h>
 #include <stdio.h>
 #include <fcntl.h>
 #include <string.h>
@@ -37,7 +37,7 @@
 
 #include "ntpctl.h"
 
-#define SZ_NTPCTL_VERSION "3.0"
+#define SZ_NTPCTL_VERSION "4.0"
 
 #define MIN_COLS		40
 #define MIN_LINES		15
@@ -84,6 +84,8 @@ int (*configmenuraw[])(struct menuinfo *,int) =
 
 #define CONFIGMENUSIZE	(sizeof(configmenuraw)/sizeof(configmenuraw[1]))
 
+#define DEVICE_NAME_DEFAULT "/dev/thinkpad/thinkpad"
+
 struct menuinfo configmenuinfo[CONFIGMENUSIZE];
 ITEM *configmenuitems[CONFIGMENUSIZE+1];
 char configmenuname[CONFIGMENUSIZE][MAXNAMESIZE];
@@ -298,7 +300,7 @@ handle_resume_cond(struct menuinfo *mi, int action, int bitnr)
 {
   smapi_outparm_t *result;
   int chconfig=FALSE;
-  int tmp;
+  int tmp=0;
 
   if((result=do_smapi(0x34,0x00,0,0,0,0,0,FALSE))==NULL) return 1;
 
@@ -364,7 +366,7 @@ handle_pm_mode(struct menuinfo *mi, int action, int bitnr)
 {
   smapi_outparm_t *result;
   int chconfig=FALSE;
-  int tmp;
+  int tmp=0;
 
   if((bitnr!=0) && (bitnr!=8)) return 1;
 
@@ -468,7 +470,7 @@ pm_mode_save_suspend(struct menuinfo *mi, int action)
 {
   smapi_outparm_t *result;
   int chconfig=FALSE;
-  int tmp;
+  int tmp=0;
 
   if((result=do_smapi(0x30,0x00,0,0,0,0,0,FALSE))==NULL) return 1;
 
@@ -525,7 +527,7 @@ fn_hotkey(struct menuinfo *mi, int action)
 {
   smapi_outparm_t *result;
   int chconfig=FALSE;
-  int tmp;
+  int tmp=0;
 
   if((result=do_smapi(0x13,0x02,0,0,0,0,0,FALSE))==NULL) return 1;
 
@@ -808,41 +810,39 @@ startup(void)
 
   signal(SIGINT,handle_sig_int);
 
-  if ( stat(device_name, &statBuf) ) {
-    if ( errno == ENOENT ) {
-      if ( fdevice ) { /* user specified a device name */
-        cleanup( "Device does not exist.  Exiting." );
-        exit(-1);
-      } else {
-        /* Maybe it isn't there because we have devfs and module is absent */
-        /* Try: */
-        device_name = "/dev/thinkpad/thinkpad";
-      }
-    } else { /* some other stat error */
-      cleanup( "Can't stat device.  Exiting." );
-      exit(-1);
-    }
-  }
-  if ( statBuf.st_mode & S_IFDIR ) {
-    /* Default device name is a dir */
-    if ( fdevice ) { /* user specified a device name */
-      cleanup( "Can't open device because it is a directory.  Exiting." );
-      exit(-1);
-    } else {
-      /* We're probably using devfs.  Try this */
-      device_name = "/dev/thinkpad/thinkpad";
-    }
-  }
+	if (stat(device_name,&statBuf)) {
+		if (strcmp(device_name,DEVICE_NAME_DEFAULT)) {
+			if (errno==ENOENT)
+				cleanup( "Device file does not exist" );
+			else
+				cleanup( "stat() of device file failed" );
+			exit( EXIT_FAILURE );
+		} else {
+			if (stat("/dev/thinkpad",&statBuf)) {
+				if (errno==ENOENT) 
+					cleanup( "Device file does not exist" );
+				else
+					cleanup( "stat() of device file failed" );
+				exit( EXIT_FAILURE );
+			} else {
+				device_name = "/dev/thinkpad";
+			}
+		}
+	}
+	/* stat(device_name,...) successful */
+	if ( !(statBuf.st_mode & S_IFCHR) ) {
+		cleanup("File is not a character device node." );
+		exit( EXIT_FAILURE );
+	}
+	/* The file named by device_name is a character device node */
 
-  if((device_fd=open(device_name,O_RDWR))==-1)
-    {
-      if((device_fd=open(device_name,O_RDONLY))==-1)
-        {
+  if((device_fd=open(device_name,O_RDWR))==-1) {
+      if((device_fd=open(device_name,O_RDONLY))==-1) {
           cleanup("Error while opening device.  Exiting.");
           exit(-1);
-        }                                                                       
+      }                                                                       
       dev_rdonly=TRUE;
-    }
+  }
 
   for(i=0;i<CONFIGMENUSIZE;i++) 
     {
@@ -918,7 +918,7 @@ main(int argc, char *argv[])
   char chRtn;
   int iasoCur;
 
-  device_name = "/dev/thinkpad";
+  device_name = DEVICE_NAME_DEFAULT;
 
   while(
     (chRtn = getopt_long_only(argc, argv, pchOpts, asoMyLongopts, &iasoCur )) != EOF
