@@ -245,7 +245,7 @@ int tm_hibernation(struct menuinfo *mi, int action)
 int handle_timer_control(struct menuinfo *mi, int action, int bitnr)
 {
   smapi_outparm_t *result;
-  int tmp;
+  int tmp = 0;
   int chconfig=FALSE;
 
   if((result=do_smapi(0x22,0x02,0,0,0,0,0,FALSE))==NULL) return -1;
