@@ -1,4 +1,7 @@
-#include <asm/system.h>
+/* from old <asm/system.h> */
+#define __cli()		__asm__ __volatile__("cli": : :"memory")
+#define __sti()		__asm__ __volatile__("sti": : :"memory")
+
 #include <sys/io.h>
 #include <stdio.h>
 
@@ -29,7 +32,7 @@ int main(int argc, char **argv)
         return 2;
     }
 
-    cli();
+    __cli();
 
     val94 = inb(0x94);              /* POS mask register */
     outb(0xfE, 0x94);               /* mask bit (0) for IR; changes enabled */
@@ -44,7 +47,7 @@ int main(int argc, char **argv)
     outb(val94, 0x94);              /* restore POS mask to prevent changing */
     outb(val94, 0x47);              /* pause */
 
-    sti();
+    __sti();
 
     return 0;
 }
